@@ -20,7 +20,7 @@ from astropy.io.fits.column import Column, ColDefs, TDEF_RE
 from astropy.io.fits.column import KEYWORD_NAMES as TABLE_KEYWORD_NAMES
 from astropy.io.fits.fitsrec import FITS_rec
 from astropy.io.fits.header import Header
-from astropy.io.fits.util import (_is_pseudo_unsigned, _unsigned_zero, _is_int,
+from astropy.io.fits.util import (_is_pseudo_integer, _pseudo_zero, _is_int,
                                   _get_array_mmap)
 
 from astropy.utils import lazyproperty
@@ -57,21 +57,7 @@ DEFAULT_HCOMP_SMOOTH = 0
 DEFAULT_BLOCK_SIZE = 32
 DEFAULT_BYTE_PIX = 4
 
-CMTYPE_ALIASES = {}
-
-# CFITSIO version-specific features
-if COMPRESSION_SUPPORTED:
-    try:
-        CFITSIO_SUPPORTS_GZIPDATA = compression.CFITSIO_VERSION >= 3.28
-        CFITSIO_SUPPORTS_Q_FORMAT = compression.CFITSIO_VERSION >= 3.35
-        if compression.CFITSIO_VERSION >= 3.35:
-            CMTYPE_ALIASES['RICE_ONE'] = 'RICE_1'
-    except AttributeError:
-        # This generally shouldn't happen unless running pip in an
-        # environment where an old build of pyfits exists
-        CFITSIO_SUPPORTS_GZIPDATA = True
-        CFITSIO_SUPPORTS_Q_FORMAT = True
-
+CMTYPE_ALIASES = {'RICE_ONE': 'RICE_1'}
 
 COMPRESSION_KEYWORDS = {'ZIMAGE', 'ZCMPTYPE', 'ZBITPIX', 'ZNAXIS', 'ZMASKCMP',
                         'ZSIMPLE', 'ZTENSION', 'ZEXTEND'}
@@ -828,12 +814,6 @@ class CompImageHDU(BinTableHDU):
         # almost entirely contrived corner cases, so it will do for now
         if self._has_data:
             huge_hdu = self.data.nbytes > 2 ** 32
-
-            if huge_hdu and not CFITSIO_SUPPORTS_Q_FORMAT:
-                raise OSError(
-                    "Astropy cannot compress images greater than 4 GB in size "
-                    "({} is {} bytes) without CFITSIO >= 3.35".format(
-                        (self.name, self.ver), self.data.nbytes))
         else:
             huge_hdu = False
 
@@ -882,10 +862,14 @@ class CompImageHDU(BinTableHDU):
             if bzero != 0.0:
                 self._header.set('BZERO', bzero, after=after_keyword)
 
+        try:
             bitpix_comment = image_header.comments['BITPIX']
-            naxis_comment = image_header.comments['NAXIS']
-        else:
+        except (AttributeError, KeyError):
             bitpix_comment = 'data type of original image'
+
+        try:
+            naxis_comment = image_header.comments['NAXIS']
+        except (AttributeError, KeyError):
             naxis_comment = 'dimension of original image'
 
         # Set the label for the first column in the table
@@ -926,25 +910,11 @@ class CompImageHDU(BinTableHDU):
             # this behavior so the only way to determine which behavior will
             # be employed is via the CFITSIO version
 
-            if CFITSIO_SUPPORTS_GZIPDATA:
-                ttype2 = 'GZIP_COMPRESSED_DATA'
-                # The required format for the GZIP_COMPRESSED_DATA is actually
-                # missing from the standard docs, but CFITSIO suggests it
-                # should be 1PB, which is logical.
-                tform2 = '1QB' if huge_hdu else '1PB'
-            else:
-                # Q format is not supported for UNCOMPRESSED_DATA columns.
-                ttype2 = 'UNCOMPRESSED_DATA'
-                if zbitpix == 8:
-                    tform2 = '1QB' if huge_hdu else '1PB'
-                elif zbitpix == 16:
-                    tform2 = '1QI' if huge_hdu else '1PI'
-                elif zbitpix == 32:
-                    tform2 = '1QJ' if huge_hdu else '1PJ'
-                elif zbitpix == -32:
-                    tform2 = '1QE' if huge_hdu else '1PE'
-                else:
-                    tform2 = '1QD' if huge_hdu else '1PD'
+            ttype2 = 'GZIP_COMPRESSED_DATA'
+            # The required format for the GZIP_COMPRESSED_DATA is actually
+            # missing from the standard docs, but CFITSIO suggests it
+            # should be 1PB, which is logical.
+            tform2 = '1QB' if huge_hdu else '1PB'
 
             # Set up the second column for the table that will hold any
             # uncompressable data.
@@ -1682,10 +1652,10 @@ class CompImageHDU(BinTableHDU):
         # write to a buffer for compression or something. See ticket #88
         # deal with unsigned integer 16, 32 and 64 data
         old_data = self.data
-        if _is_pseudo_unsigned(self.data.dtype):
+        if _is_pseudo_integer(self.data.dtype):
             # Convert the unsigned array to signed
             self.data = np.array(
-                self.data - _unsigned_zero(self.data.dtype),
+                self.data - _pseudo_zero(self.data.dtype),
                 dtype=f'=i{self.data.dtype.itemsize}')
             should_swap = False
         else:
@@ -1856,7 +1826,7 @@ class CompImageHDU(BinTableHDU):
 
             # Use methods in the superclass to update the header with
             # scale/checksum keywords based on the data type of the image data
-            self._update_uint_scale_keywords()
+            self._update_pseudo_int_scale_keywords()
 
             # Shove the image header and data into a new ImageHDU and use that
             # to compute the image checksum
